aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/gpu/GrGpuResource.h
diff options
context:
space:
mode:
authorGravatar bsalomon <bsalomon@google.com>2015-02-11 10:49:59 -0800
committerGravatar Commit bot <commit-bot@chromium.org>2015-02-11 10:49:59 -0800
commit0ea80f43a1af05b8157a4ef387223bb5b0da35ed (patch)
tree5eac85169535b5a2c94f7beafdb1d024e220dcc2 /include/gpu/GrGpuResource.h
parent5a4c233a3657d12d836de388b41e30405b4ab976 (diff)
Rename GrResourceCache2->GrResourceCache
TBR=robertphillips@google.com Review URL: https://codereview.chromium.org/921453002
Diffstat (limited to 'include/gpu/GrGpuResource.h')
-rw-r--r--include/gpu/GrGpuResource.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/gpu/GrGpuResource.h b/include/gpu/GrGpuResource.h
index dcb4a47d2c..8e983d89c5 100644
--- a/include/gpu/GrGpuResource.h
+++ b/include/gpu/GrGpuResource.h
@@ -16,7 +16,7 @@
class GrContext;
class GrGpu;
-class GrResourceCache2;
+class GrResourceCache;
/**
* Base class for GrGpuResource. Handles the various types of refs we need. Separated out as a base
@@ -113,13 +113,13 @@ private:
// This class is used to manage conversion of refs to pending reads/writes.
friend class GrGpuResourceRef;
- friend class GrResourceCache2; // to check IO ref counts.
+ friend class GrResourceCache; // to check IO ref counts.
template <typename, GrIOType> friend class GrPendingIOResource;
};
/**
* Base class for objects that can be kept in the GrResourceCache2.
*/
class SK_API GrGpuResource : public GrIORef<GrGpuResource> {
public:
@@ -276,7 +276,7 @@ private:
static uint32_t CreateUniqueID();
// We're in an internal doubly linked list owned by GrResourceCache2
SK_DECLARE_INTERNAL_LLIST_INTERFACE(GrGpuResource);
@@ -113,13 +113,13 @@ private:
};
/**
- * Base class for objects that can be kept in the GrResourceCache2.
+ * Base class for objects that can be kept in the GrResourceCache.
*/
class SK_API GrGpuResource : public GrIORef<GrGpuResource> {
@@ -276,7 +276,7 @@ private:
static uint32_t CreateUniqueID();
- // We're in an internal doubly linked list owned by GrResourceCache2
+ // We're in an internal doubly linked list owned by GrResourceCache
SK_DECLARE_INTERNAL_LLIST_INTERFACE(GrGpuResource);